@@ -25,8 +25,7 @@
 
 #include <QStringBuilder>
 #include <QPainter>
-
-#include <KDebug>
+#include <QUrl>
 
 ChooseSocket::ChooseSocket(QWidget *parent) :
     GenericPage(parent),
@@ -54,8 +53,8 @@ void ChooseSocket::setValues(const QVariantHash &args)
     ui->addressLE->clear();
     ui->portISB->setValue(9100);
     QString deviceUri = args[KCUPS_DEVICE_URI].toString();
-    KUrl url = deviceUri;
-    if (url.scheme() == QLatin1String("socket")) {
+    QUrl url = deviceUri;
+    if (url.scheme() == QStringLiteral("socket")) {
         ui->addressLE->setText(url.host());
         ui->portISB->setValue(url.port(9100));
     }
@@ -67,9 +66,9 @@ void ChooseSocket::setValues(const QVariantHash &args)
 QVariantHash ChooseSocket::values() const
 {
     QVariantHash ret = m_args;
-    KUrl url = KUrl(QLatin1String("socket://") % ui->addressLE->text());
+    QUrl url = QUrl(QStringLiteral("socket://") % ui->addressLE->text());
     url.setPort(ui->portISB->value());
-    ret[KCUPS_DEVICE_URI] = url.prettyUrl();
+    ret[KCUPS_DEVICE_URI] = url.toDisplayString();
     return ret;
 }
 
