@@ -26,7 +26,8 @@
 #include <KCupsRequest.h>
 
 #include <QPainter>
-#include <KDebug>
+
+#include <KIconLoader>
 
 PageChoosePrinters::PageChoosePrinters(const QVariantHash &args, QWidget *parent) :
     GenericPage(parent),
